@@ -1,12 +1,16 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.6 2005/03/13 19:51:31 bkorb Exp $
+ *  $Id: autogen.h,v 4.25 2006/09/28 01:26:33 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-27 11:42:20 bkorb"
+ *  Last Committed:    $Date: 2006/09/28 01:26:33 $
+ *
  *  Global header file for AutoGen
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -21,16 +25,17 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
-#ifndef AUTOGEN_HDR_H
-#define AUTOGEN_HDR_H
+#ifndef AUTOGEN_BUILD
+#define AUTOGEN_BUILD 1
 
 #include "config.h"
 #include "compat/compat.h"
 
 #include REGEX_HEADER
+#include <libguile/scmconfig.h>
 #include <guile/gh.h>
 
 #include "opts.h"
@@ -56,6 +61,8 @@
 
 #define YYSTYPE t_word
 
+#define ag_offsetof(TYPE, MEMBER) ((unsigned long) &((TYPE *)0)->MEMBER)
+
 /*
  *  Dual pipe opening of a child process
  */
@@ -122,9 +129,12 @@ typedef struct template_lib_marker tTlibMark;
  *
  *  Procedure for loading a template function
  */
-typedef tMacro* (tLoadProc)( tTemplate*, tMacro*, const char** ppzScan );
+typedef tMacro* (tLoadProc)( tTemplate*, tMacro*, char const** ppzScan );
 typedef tLoadProc* tpLoadProc;
 
+typedef void (tUnloadProc)( tMacro* );
+typedef tUnloadProc* tpUnloadProc;
+
 /*
  *  Procedure for handling a template function
  *  during the text emission phase.
@@ -146,11 +156,11 @@ typedef tHdlrProc* tpHdlrProc;
 
 struct template_lib_marker {
     union {
-        char        str[4];  /* {'A', 'G', 'L', 'B'} */
-        long        i[1];
+        unsigned char   str[4];  /* {'A', 'G', 'L', 'B'} */
+        unsigned int    i[1];
     }           magic;
-    short       revision;    /* TEMPLATE_REVISION    */
-    short       funcSum;     /* FUNCTION_CKSUM       */
+    unsigned short      revision;    /* TEMPLATE_REVISION    */
+    unsigned short      funcSum;     /* FUNCTION_CKSUM       */
 };
 
 /*
@@ -186,12 +196,11 @@ struct macro_desc {
 
 struct template_desc {
     tTlibMark   magic;       /* TEMPLATE_MAGIC_MARKER    */
-    int         fd;          /* mmap file descriptor     */
     size_t      descSize;    /* Structure Size           */
     char*       pNext;       /* Next Pointer             */
     int         macroCt;     /* Count of Macros          */
-    tCC*        pzFileName;  /* Name of Macro File       */
-    char*       pzTplName;   /* Template Name Pointer    */
+    tCC*        pzTplFile;   /* Name of template file    */
+    char*       pzTplName;   /* Defined Macro Name       */
     char*       pzTemplText; /* offset of the text       */
     char        zStartMac[MAX_SUFFIX_LEN];
     char        zEndMac[MAX_SUFFIX_LEN];
@@ -246,7 +255,7 @@ struct scanContext {
 
 struct outSpec {
     tOutSpec*   pNext;
-    const char* pzFileFmt;
+    char const* pzFileFmt;
     char        zSuffix[ 1 ];
 };
 
@@ -263,13 +272,6 @@ struct fpStack {
     tCC*        pzOutName;
 };
 
-typedef struct {
-    tCC*        pzFileName;
-    int         fd;
-    size_t      size;
-    void*       pData;
-} tMapInfo;
-
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  FOR loop processing state
@@ -376,10 +378,11 @@ MODE int         templLineNo      VALUE( 1 );
 MODE tScanCtx*   pBaseCtx         VALUE( NULL );
 MODE tScanCtx*   pCurCtx          VALUE( NULL );
 MODE tScanCtx*   pDoneCtx         VALUE( NULL );
-MODE int         endMacLen        VALUE( 0  );
+MODE u_int       endMacLen        VALUE( 0  );
 MODE char        zEndMac[   8 ]   VALUE( "" );
-MODE int         startMacLen      VALUE( 0  );
+MODE u_int       startMacLen      VALUE( 0  );
 MODE char        zStartMac[  8 ]  VALUE( "" );
+MODE int         guileFailure     VALUE( 0 );
 
 /*
  *  Definition Parsing Globals
@@ -400,7 +403,7 @@ MODE tDefEntry*  pCurrentEntry    VALUE( NULL );
  *  GLOBAL STRINGS
  */
 #define MKSTRING( name, val ) \
-        MODE const char z ## name[ sizeof( val )] VALUE( val )
+        MODE char const z ## name[ sizeof( val )] VALUE( val )
 
 MKSTRING( AllocWhat,  "Could not allocate a %d byte %s\n" );
 MKSTRING( AllocErr,   "Allocation Failure" );
@@ -411,6 +414,7 @@ MKSTRING( ShDone,     "ShElL-OuTpUt-HaS-bEeN-cOmPlEtEd" );
 MKSTRING( NotStr,     "ERROR: %s is not a string\n" );
 MKSTRING( DevNull,    "/dev/null" );
 MKSTRING( ShellEnv,   "SHELL" );
+MKSTRING( Format,     "format" );
 
 /*
  *  It may seem odd that there are two 'nil' strings.  It is used by
@@ -425,31 +429,20 @@ MKSTRING( ShellEnv,   "SHELL" );
 MKSTRING( Nil,        "" );
 MKSTRING( DefaultNil, "" );
 
-extern void unloadTemplate( tTemplate* pT );
-extern void unloadDefs( void );
-
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  GLOBAL PROCEDURES
  */
 #ifndef HAVE_STRLCPY
-extern size_t strlcpy( char* dest, const char* src, size_t n );
+extern size_t strlcpy( char* dest, char const* src, size_t n );
 #endif
 #ifdef ENABLE_FMEMOPEN
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
- *  IF we have fopencookie or funopen, then we also have our own fmemopen...
- *
- *  Special ioctl/"seek" requests
+ *  IF we have fopencookie or funopen, then we also have our own fmemopen
  */
-#define FMEM_IOCTL_BUF_ADDR  0x80000001
 
-/*
- *  Save the buffer on close
- */
-#define FMEM_IOCTL_SAVE_BUF  0x80000002
-
-extern FILE * ag_fmemopen (void *buf, ssize_t len, const char *mode);
+extern FILE * ag_fmemopen (void *buf, ssize_t len, char const *mode);
 #endif
 #include "proto.h"
 
@@ -473,15 +466,97 @@ MODE v2c_t p2p VALUE( { NULL } );
 #define AG_ABEND_IN(t,m,s) \
     STMTS( pCurTemplate=(t); pCurMacro=(m); AG_ABEND(s);)
 
-static inline char* ag_scm2zchars( SCM s, tCC* type )
-{
-    if (! gh_string_p( s ))
+extern void  ag_scmStrings_init(   void );
+extern void  ag_scmStrings_deinit( void );
+extern void  ag_scmStrings_free(   void );
+extern char* ag_scribble( size_t size );
+
+#if defined(DEBUG_ENABLED)
+  extern void manageAllocatedData( void* pd );
+#else
+# define manageAllocatedData(_ptr)
+#endif
+
+/*
+ *  Code variations based on the version of Guile:
+ */
+#if GUILE_VERSION < 107000  /* pre-Guile 1.7.x */
+
+#if GUILE_VERSION < 106000 /* Guile 1.4 */
+
+#   define AG_SCM_STRING_P(_s)          gh_string_p(_s)
+#   define AG_SCM_BOOL_P(_b)            gh_boolean_p(_b)
+#   define AG_SCM_SYM_P(_s)             gh_symbol_p(_s)
+#   define AG_SCM_IS_PROC(_p)           gh_procedure_p(_p)
+#   define AG_SCM_CHAR_P(_c)            gh_char_p(_c)
+#   define AG_SCM_VEC_P(_v)             gh_vector_p(_v)
+#   define AG_SCM_PAIR_P(_p)            gh_pair_p(_p)
+#   define AG_SCM_NUM_P(_n)             gh_number_p(_n)
+#   define AG_SCM_LIST_P(_l)            gh_list_p(_l)
+#   define AG_SCM_STR2SCM(_st,_sz)      gh_str2scm(_st,_sz)
+#   define AG_SCM_STR02SCM(_s)          gh_str02scm(_s)
+
+#else /* Guile 1.6.x */
+
+#   define AG_SCM_STRING_P(_s)          SCM_STRINGP(_s)
+#   define AG_SCM_BOOL_P(_b)            SCM_BOOLP(_b)
+#   define AG_SCM_SYM_P(_s)             SCM_SYMBOLP(_s)
+#   define AG_SCM_IS_PROC(_p)           SCM_NFALSEP( scm_procedure_p(_p))
+#   define AG_SCM_CHAR_P(_c)            SCM_CHARP(_c)
+#   define AG_SCM_VEC_P(_v)             SCM_VECTORP(_v)
+#   define AG_SCM_PAIR_P(_p)            SCM_NFALSEP( scm_pair_p(_p))
+#   define AG_SCM_NUM_P(_n)             SCM_NUMBERP(_n)
+#   define AG_SCM_LIST_P(_l)            SCM_NFALSEP( scm_list_p(_l))
+#   define AG_SCM_STR2SCM(_st,_sz)      scm_mem2string(_st,_sz)
+#   define AG_SCM_STR02SCM(_s)          scm_makfrom0str(_s)
+#endif
+
+  static inline char* ag_scm2zchars( SCM s, tCC* type )
+  {
+    if (! AG_SCM_STRING_P( s ))
         AG_ABEND( aprf( zNotStr, type ));
 
     if (SCM_SUBSTRP(s))
-        s = scm_makfromstr( SCM_ROCHARS(s), SCM_ROLENGTH(s), 0 );
+        s = scm_makfromstr( SCM_CHARS(s), SCM_LENGTH(s), 0 );
     return SCM_CHARS(s);
-}
+  }
+
+# define AG_SCM_STRLEN(_s)              SCM_LENGTH(_s)
+# define AG_SCM_CHARS(_s)               SCM_CHARS(_s)
+
+#else /* Guile 1.7 and following */
+
+  extern char* ag_scm2zchars( SCM s, tCC* type );
+
+# if GUILE_VERSION < 108000
+#   define AG_SCM_STRLEN(_s)            SCM_STRING_LENGTH(_s)
+#   define AG_SCM_CHARS(_s)             SCM_STRING_CHARS(_s)
+#   define AG_SCM_VEC_P(_v)             SCM_VECTORP(_v)
+# else
+#   define AG_SCM_STRLEN(_s)            scm_c_string_length(_s)
+#   define AG_SCM_CHARS(_s)             scm_i_string_chars(_s)
+#   define AG_SCM_VEC_P(_v)             scm_is_vector(_v)
+# endif
+
+# define AG_SCM_STRING_P(_s)            scm_is_string(_s)
+# define AG_SCM_BOOL_P(_b)              SCM_BOOLP(_b)
+# define AG_SCM_SYM_P(_s)               SCM_SYMBOLP(_s)
+# define AG_SCM_IS_PROC(_p)             scm_is_true( scm_procedure_p(_p))
+# define AG_SCM_CHAR_P(_c)              SCM_CHARP(_c)
+# define AG_SCM_PAIR_P(_p)              scm_is_true( scm_pair_p(_p))
+# define AG_SCM_NUM_P(_n)               scm_is_number(_n)
+# define AG_SCM_LIST_P(_l)              SCM_NFALSEP( scm_list_p(_l))
+# define AG_SCM_STR2SCM(_st,_sz)        scm_from_locale_stringn(_st,_sz)
+# define AG_SCM_STR02SCM(_s)            scm_from_locale_string(_s)
+#endif /* pre-1.7 / 1.7 and following */
+
+/*
+ *  Guile version invariant!!
+ */
+#define AG_SCM_INT2SCM(_i)              gh_int2scm(_i)
+#define AG_SCM_SCM2INT(_i)              gh_scm2int(_i)
+#define AG_SCM_LONG2SCM(_i)             gh_long2scm(_i)
+#define AG_SCM_SCM2LONG(_i)             gh_scm2long(_i)
 
 static inline SCM ag_eval( tCC* pzStr )
 {
@@ -490,18 +565,17 @@ static inline SCM ag_eval( tCC* pzStr )
     pzLastScheme = pzStr;
 
     res = ag_scm_c_eval_string_from_file_line(
-        pzStr, pCurTemplate->pzFileName, pCurMacro->lineNo );
+        pzStr, pCurTemplate->pzTplFile, pCurMacro->lineNo );
 
     pzLastScheme = pzSaveScheme;
     return res;
 }
 
-#endif /* AUTOGEN_HDR */
+#endif /* AUTOGEN_BUILD */
 /*
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/autogen.h */
