@@ -1,13 +1,13 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Thursday December 15, 2005 at 03:11:44 PM PST
+ *  It has been AutoGen-ed  Saturday October 14, 2006 at 04:42:41 PM PDT
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
  *  Automated Finite State Machine
  *
- *  Copyright (c) 2001-2005  by  Bruce Korb
+ *  Copyright (c) 2001-2006  by  Bruce Korb
  *
  *  AutoFSM is free software copyrighted by Bruce Korb.
  *  
@@ -53,10 +53,6 @@
 #  define NULL 0
 #endif
 
-#ifndef tSCC
-#  define tSCC static const char
-#endif
-
 /*
  *  Enumeration of the valid transition types
  *  Some transition types may be common to several transitions.
@@ -121,61 +117,51 @@ cgi_trans_table[ CGI_STATE_CT ][ CGI_EVENT_CT ] = {
 };
 
 
-tSCC zCgiStrings[] =
-       "** OUT-OF-RANGE **" "\0"
-       "FSM Error:  in state %d (%s), event %d (%s) is invalid\n" "\0"
-       "invalid" "\0"
-       "init" "\0"
-       "name" "\0"
-       "value" "\0"
-       "alpha" "\0"
-       "name_char" "\0"
-       "=" "\0"
-       "+" "\0"
-       "%" "\0"
-       "other" "\0"
-       "&" "\0"
-       "end" "\0";
-
-#define CgiBogus_off 0
-#define CgiFsmErr_off 19
-#define CgiEvInvalid_off 75
-#define CgiStInit_off 83
-#define CgiStName_off 88
-#define CgiStValue_off 93
-#define CgiEvAlpha_off 99
-#define CgiEvName_Char_off 105
-#define CgiEvEqual_off 115
-#define CgiEvSpace_off 117
-#define CgiEvEscape_off 119
-#define CgiEvOther_off 121
-#define CgiEvSeparator_off 127
-#define CgiEvEnd_off 129
+#define CgiFsmErr_off     19
+#define CgiEvInvalid_off  75
+#define CgiStInit_off     83
 
 
-static const size_t aszCgiStates[] = {
-    CgiStInit_off,  CgiStName_off,  CgiStValue_off };
+static char const zCgiStrings[133] =
+    "** OUT-OF-RANGE **\0"
+    "FSM Error:  in state %d (%s), event %d (%s) is invalid\n\0"
+    "invalid\0"
+    "init\0"
+    "name\0"
+    "value\0"
+    "alpha\0"
+    "name_char\0"
+    "=\0"
+    "+\0"
+    "%\0"
+    "other\0"
+    "&\0"
+    "end\0";
 
-static const size_t aszCgiEvents[] = {
-    CgiEvAlpha_off,     CgiEvName_Char_off, CgiEvEqual_off,
-    CgiEvSpace_off,     CgiEvEscape_off,    CgiEvOther_off,
-    CgiEvSeparator_off, CgiEvEnd_off,       CgiEvInvalid_off };
+static const size_t aszCgiStates[3] = {
+    83, 88, 93 };
 
-#define CGI_EVT_NAME(t) ( (((unsigned)(t)) >= CGI_EV_INVALID) \
+static const size_t aszCgiEvents[9] = {
+    99,  105, 115, 117, 119, 121, 127, 129, 75 };
+
+
+#define CGI_EVT_NAME(t)   ( (((unsigned)(t)) >= 9) \
     ? zCgiStrings : zCgiStrings + aszCgiEvents[t])
 
-#define CGI_STATE_NAME(s) ( (((unsigned)(s)) > CGI_ST_INVALID) \
+#define CGI_STATE_NAME(s) ( (((unsigned)(s)) >= 3) \
     ? zCgiStrings : zCgiStrings + aszCgiStates[s])
 
 #ifndef EXIT_FAILURE
 # define EXIT_FAILURE 1
 #endif
 
+static int cgi_invalid_transition( te_cgi_state st, te_cgi_event evt );
+
 /* * * * * * * * * THE CODE STARTS HERE * * * * * * * *
  *
  *  Print out an invalid transition message and return EXIT_FAILURE
  */
-int
+static int
 cgi_invalid_transition( te_cgi_state st, te_cgi_event evt )
 {
     /* START == INVALID TRANS MSG == DO NOT CHANGE THIS COMMENT */
@@ -193,7 +179,7 @@ cgi_invalid_transition( te_cgi_state st, te_cgi_event evt )
  */
 te_cgi_state
 cgi_run_fsm(
-    const char* pzSrc,
+    char const* pzSrc,
     int inlen,
     char* pzOut,
     int outlen )
@@ -338,7 +324,6 @@ cgi_run_fsm(
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of cgi-fsm.c */
