@@ -1,11 +1,14 @@
 /*
- *  $Id: defFind.c,v 4.6 2005/11/25 19:00:27 bkorb Exp $
+ *  $Id: defFind.c,v 4.11 2006/09/24 02:58:59 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:55:01 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:58:59 $
  *
  *  This module locates definitions.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -40,7 +43,7 @@ static tDefEntry* findEntryByIndex( tDefEntry* pE, char* pzScan );
 
 #define ILLFORMEDNAME() \
     AG_ABEND( aprf( zNameRef, zDefinitionName, \
-              pCurTemplate->pzFileName, pCurMacro->lineNo ));
+              pCurTemplate->pzTplFile, pCurMacro->lineNo ));
 
 
 /* = = = START-STATIC-FORWARD = = = */
@@ -52,7 +55,7 @@ static void
 addResult( tDefEntry* pDE, tDefEntryList* pDEL );
 
 static size_t
-badName( char* pzD, const char* pzS, size_t srcLen );
+badName( char* pzD, char const* pzS, size_t srcLen );
 
 static tDefEntry*
 defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed );
@@ -106,7 +109,7 @@ findEntryByIndex( tDefEntry* pE, char* pzScan )
          *  '[XX]' means get the index from our definitions
          */
         char* pzDef = pzScan;
-        const char* pzVal;
+        char const* pzVal;
 
         if (! isalpha( *pzScan ))
             return NULL;
@@ -182,12 +185,12 @@ addResult( tDefEntry* pDE, tDefEntryList* pDEL )
 
 
 static size_t
-badName( char* pzD, const char* pzS, size_t srcLen )
+badName( char* pzD, char const* pzS, size_t srcLen )
 {
     memcpy( (void*)pzD, (void*)pzS, srcLen );
     pzD[ srcLen ] = NUL;
     fprintf( pfTrace, zNameRef, pzD,
-             pCurTemplate->pzFileName, pCurMacro->lineNo );
+             pCurTemplate->pzTplFile, pCurMacro->lineNo );
     return srcLen + 1;
 }
 
@@ -203,7 +206,7 @@ badName( char* pzD, const char* pzS, size_t srcLen )
  *  We start in CN_START.
  */
 LOCAL int
-canonicalizeName( char* pzD, const char* pzS, int srcLen )
+canonicalizeName( char* pzD, char const* pzS, int srcLen )
 {
     typedef enum {
         CN_START_NAME = 0,   /* must find a name */
@@ -215,7 +218,7 @@ canonicalizeName( char* pzD, const char* pzS, int srcLen )
 
     teConState state = CN_START_NAME;
 
-    const char* pzOri = pzS;
+    char const* pzOri = pzS;
     char*       pzDst = pzD;
     size_t      stLen = srcLen;
 
@@ -404,7 +407,7 @@ defEntrySearch( char* pzName, tDefCtx* pDefCtx, ag_bool* pIsIndexed )
      *  an index yet).
      */
     if (nestingDepth == 0) {
-        canonicalizeName( zDefinitionName, pzName, strlen( pzName ));
+        canonicalizeName( zDefinitionName, pzName, (int)strlen( pzName ));
         pzName = zDefinitionName;
 
         if (pIsIndexed != NULL)
@@ -585,7 +588,7 @@ entryListSearch( char* pzName, tDefCtx* pDefCtx )
      *  an index yet).
      */
     if (defList.nestLevel == 0) {
-        canonicalizeName( zDefinitionName, pzName, strlen( pzName ));
+        canonicalizeName( zDefinitionName, pzName, (int)strlen( pzName ));
         pzName = zDefinitionName;
         defList.usedCt = 0;
 
@@ -752,7 +755,6 @@ findEntryList( char* pzName )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/defFind.c */
