@@ -1,6 +1,10 @@
 
 /*
- *  $Id: defLex.c,v 4.13 2006/06/24 23:36:07 bkorb Exp $
+ *  $Id: defLex.c,v 4.16 2006/09/24 02:58:59 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:54:51 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  */
@@ -219,7 +223,7 @@ scanAgain:
             pzShellProgram = getDefine( zShellEnv, AG_TRUE );
 
         lastToken = DP_EV_STRING;
-        pz = runShell( (const char*)pz_token );
+        pz = runShell( (char const*)pz_token );
         if (pz == NULL)
             goto scanAgain;
         TAGMEM( pz, "shell definition string" );
@@ -664,7 +668,6 @@ assembleHereString( char* pzScan )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/defLex.c */
