@@ -1,6 +1,9 @@
 
 ;;;  AutoGen copyright 1992-2006 Bruce Korb
 ;;;
+;;; Time-stamp:        "2006-10-14 16:33:33 bkorb"
+;;; Last Committed:    $Date: 2006/10/14 23:40:29 $
+;;;
 ;;; AutoGen is free software.
 ;;; You may redistribute it and/or modify it under the terms of the
 ;;; GNU General Public License, as published by the Free Software
@@ -20,7 +23,7 @@
 ;;; This module defines all the scheme initialization for AutoGen.
 ;;; It gets sucked up into directives.h as a single ANSI-C string.
 ;;; Comments, blank lines and leading white space are omitted.
-
+;;;
 (use-modules (ice-9 common-list))
 
 (define identifier?
@@ -88,6 +91,21 @@
 ) ) ) ) ) )         )
 
 (define shell-cleanup "")
+(define add-cleanup (lambda (t)
+   (set! shell-cleanup (string-append shell-cleanup "\n" t "\n"))  ))
+(define tmp-dir "")
+(define make-tmp-dir
+  (lambda () 
+    (begin (set! tmp-dir (shell
+  "tmp_dir=`mktemp -d ./.ag-XXXXXX` 2>/dev/null
+  test -d \"${tmp_dir}\" || {
+    tmp_dir=${TMPDIR:-/tmp}/.ag-$$
+    mkdir ${tmp_dir} || die cannot mkdir ${tmp_dir}
+  } ; echo ${tmp_dir}" ))
+
+  (add-cleanup (string-append  "rm -rf " tmp-dir))
+
+)))
 
 ;;; /*=gfunc   make_header_guard
 ;;;  *
@@ -128,20 +146,20 @@
 ;;;  *   The final @code{#define} name is stored in an SCM symbol named
 ;;;  *   @code{header-guard}.  Consequently, the concluding @code{#endif} for the
 ;;;  *   file should read something like:
-;;;  *	 
+;;;  *
 ;;;  *   @example
 ;;;  *   #endif /* [+ (. header-guard) +] */
 ;;;  *   @end example
-;;;  *   
-;;;  *	 The name of the header file (the current output file) is also stored
+;;;  *
+;;;  *   The name of the header file (the current output file) is also stored
 ;;;  *   in an SCM symbol, @code{header-file}.  Therefore, if you are also
 ;;;  *   generating a C file that uses the previously generated header file,
 ;;;  *   you can put this into that generated file:
-;;;  *   
+;;;  *
 ;;;  *   @example
 ;;;  *   #include "[+ (. header-file) +]"
 ;;;  *   @end example
-;;;  *   
+;;;  *
 ;;;  *   Obviously, if you are going to produce more than one header file from
 ;;;  *   a particular template, you will need to be careful how these SCM symbols
 ;;;  *   get handled.
@@ -213,7 +231,7 @@
 ;;;  *    `'   (out-push-new)
 ;;;  *    `'   (define ix 0)
 ;;;  *    `'   (define ct 1)  +][+
-;;;  *      
+;;;  *
 ;;;  *      FOR str IN that was the week that was +][+
 ;;;  *    `'  (set! ct (+ ct 1))
 ;;;  *    `'  (set! ix (string-table-add "scribble" (get "str")))
@@ -223,7 +241,7 @@
 ;;;  *    `'    NULL @};
 ;;;  *      [+ (out-suspend "main")
 ;;;  *    `'   (emit-string-table "scribble")
-;;;  *    `'   (ag-fprintf 0 "\nconst char *ap[%d] = @{" ct)
+;;;  *    `'   (ag-fprintf 0 "\nchar const *ap[%d] = @{" ct)
 ;;;  *    `'   (out-resume "main")
 ;;;  *    `'   (out-pop #t) +]
 ;;;  *   @end example
@@ -249,10 +267,10 @@
 ;;;  *   in the string table:
 ;;;  *
 ;;;  *   @example
-;;;  *      static const char scribble[18] =
+;;;  *      static char const scribble[18] =
 ;;;  *    `'    "that\0" "was\0"  "the\0"  "week\0";
 ;;;  *
-;;;  *      const char *ap[7] = @{
+;;;  *      char const *ap[7] = @{
 ;;;  *    `'    scribble + 0,
 ;;;  *    `'    scribble + 5,
 ;;;  *    `'    scribble + 9,
@@ -314,6 +332,23 @@
    stt-idx
 )))
 
+;;; /*=gfunc   string_table_add_ref
+;;;  *
+;;;  * what:   Add an entry to a string table, get reference
+;;;  * general-use:
+;;;  *
+;;;  * exparg: st-name , the name of the array of characters
+;;;  * exparg: str-val , the (possibly) new value to add
+;;;  *
+;;;  * doc:    Identical to string-table-add, except the value returned
+;;;  *         is the string "st-name" '+' and the index returned by
+;;;  *         string-table-add.
+;;; =*/
+;;;
+(define string-table-add-ref (lambda (st-name str-val)
+   (string-append st-name "+"
+      (number->string (string-table-add st-name str-val)) ) ))
+
 ;;; /*=gfunc   emit_string_table
 ;;;  *
 ;;;  * what:   output a string table
@@ -322,14 +357,14 @@
 ;;;  * exparg: st-name , the name of the array of characters
 ;;;  *
 ;;;  * doc:    Emit into the current output stream a
-;;;  *         @code{static const char} array named @code{st-name}
+;;;  *         @code{static char const} array named @code{st-name}
 ;;;  *         that will have @code{NUL} bytes between each inserted string.
 ;;; =*/
 ;;;
 (define emit-string-table (lambda (st-name) (begin
    (set! stt-curr (hash-ref stt-table   st-name))
    (set! stt-idx  (hash-ref stt-curr "current-index"))
-   (ag-fprintf 0 "\nstatic const char %s[%d] =\n" st-name stt-idx)
+   (ag-fprintf 0 "\nstatic char const %s[%d] =\n" st-name stt-idx)
    (out-resume st-name)
 
    ;; Columnize the output.
@@ -344,6 +379,67 @@
    (emit ";\n")
 )))
 
+;;; /*=gfunc   string_table_size
+;;;  *
+;;;  * what:   print the current size of a string table
+;;;  * general-use:
+;;;  *
+;;;  * exparg: st-name , the name of the array of characters
+;;;  *
+;;;  * doc:    Returns the current byte count of the string table.
+;;; =*/
+;;;
+(define string-table-size (lambda (st-name)
+  (hash-ref (hash-ref stt-table st-name) "current-index") ))
+
+;;; /*=gfunc   gperf_code
+;;;  *
+;;;  * what:   emit the source of the generated gperf program
+;;;  * general-use:
+;;;  *
+;;;  * exparg: st-name , the name of the gperf hash list
+;;;  *
+;;;  * doc:
+;;;  *  Returns the contents of the emitted code, suitable
+;;;  *  for inclusion in another program.  The interface contains
+;;;  *  the following elements:
+;;;  *
+;;;  *  @table @samp
+;;;  *  @item struct @i{<st-name>}_index
+;;;  *  containg the fields: @code{@{char const * name, int const id; @};}
+;;;  *
+;;;  *  @item @i{<st-name>}_hash()
+;;;  *  This is the hashing function with local only scope (static).
+;;;  *
+;;;  *  @item @i{<st-name>}_find()
+;;;  *  This is the searching and validation function.  The first argument
+;;;  *  is the string to look up, the second is its length.
+;;;  *  It returns a pointer to the corresponding @code{@i{<st-name>}_index}
+;;;  *  entry.
+;;;  *  @end table
+;;;  *
+;;;  *  Use this in your template as follows where "@i{<st-name>}" was
+;;;  *  set to be "@code{lookup}":
+;;;  *
+;;;  *  @example
+;;;  *  [+ (make-gperf "lookup" (join "\n" (stack "name_list")))
+;;;  *     (gperf-code "lookup") +]
+;;;  *  void my_fun(char * str) @{
+;;;  *  struct lookup_index * li = lookup_find(str, strlen(str));
+;;;  *  if (li != NULL) printf("%s yields %d\n", str, li->idx);
+;;;  *  @end example
+;;; =*/
+;;;
+(define gperf-code (lambda (gp-name) (shellf
+  "sed -e '1,/^#line/d' \
+       -e '/#include/d' \
+       -e '/#line/d' \
+       -e '/^[ \t]*$/d' \
+       -e 's/^const struct /static const struct /' \
+       -e '/^int main(/,$d' ${gpdir}/%s.c"
+  gp-name
+)))
+
 (use-modules (ice-9 debug))
 
 (read-enable 'positions)
