@@ -1,6 +1,9 @@
 
 /*
- *  $Id: tpLoad.c,v 4.11 2006/03/25 19:24:49 bkorb Exp $
+ *  $Id: tpLoad.c,v 4.13 2006/09/24 02:59:00 bkorb Exp $
+ *
+ * Time-stamp:        "2006-09-23 19:49:27 bkorb"
+ * Last Committed:    $Date: 2006/09/24 02:59:00 $
  *
  *  This module will load a template and return a template structure.
  */
@@ -272,10 +275,10 @@ loadMacros( tTemplate* pT,
          *  THEN pack the text
          */
         if (ct < pT->macroCt) {
-            int   delta = sizeof(tMacro) * (pT->macroCt - ct);
-            void* data  =
+            int     delta = sizeof(tMacro) * (pT->macroCt - ct);
+            void*   data  =
                 (pT->pzTplName == NULL) ? pT->pzTemplText : pT->pzTplName;
-            int   size  = pT->pNext - (char*)data;
+            size_t  size  = pT->pNext - (char*)data;
             memmove( (void*)pMacEnd, data, size );
 
             pT->pzTemplText -= delta;
@@ -434,7 +437,6 @@ cleanup( tTemplate* pTF )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/tpLoad.c */
